# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/grouprootuser.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/grouprootuser.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\025ApiGroupRootUserProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x61pi/grouprootuser.proto\x12\x0b\x62lueapi.api\"\xb0\x02\n\rGroupRootUser\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0f\n\x07groupId\x18\x03 \x01(\t\x12\x11\n\tgroupName\x18\x04 \x01(\t\x12\x11\n\tgroupType\x18\x05 \x01(\t\x12\'\n\x04meta\x18\x06 \x01(\x0b\x32\x19.blueapi.api.FeatureFlags\x12\x1a\n\x12passwordUpdateTime\x18\x07 \x01(\t\x12\x12\n\nupdateTime\x18\x08 \x01(\t\x12\x14\n\x0cuserAccessId\x18\t \x01(\t\x12\x0e\n\x06userId\x18\n \x01(\t\x12\x1c\n\x14waveAvailabilityDays\x18\x0b \x01(\x05\x12\x16\n\x0ewaveRegistered\x18\x0c \x01(\t\x12\x12\n\nwaveStatus\x18\r \x01(\t\"\xbc\x07\n\x0c\x46\x65\x61tureFlags\x12\x17\n\x0f\x64\x61shboard_graph\x18\x01 \x01(\x08\x12\x15\n\rusage_account\x18\x02 \x01(\x08\x12\x1b\n\x13usage_account_graph\x18\x03 \x01(\x08\x12\'\n\x1fusage_account_menu_account_edit\x18\x04 \x01(\x08\x12!\n\x19usage_account_menu_budget\x18\x05 \x01(\x08\x12&\n\x1eusage_account_menu_budget_edit\x18\x06 \x01(\x08\x12#\n\x1busage_account_menu_fees_fee\x18\x07 \x01(\x08\x12&\n\x1eusage_account_menu_fees_credit\x18\x08 \x01(\x08\x12&\n\x1eusage_account_menu_fees_refund\x18\t \x01(\x08\x12*\n\"usage_account_menu_fees_other_fees\x18\n \x01(\x08\x12\x1d\n\x15usage_report_download\x18\x0b \x01(\x08\x12\x13\n\x0busage_group\x18\x0c \x01(\x08\x12\x19\n\x11usage_group_graph\x18\r \x01(\x08\x12\x11\n\tusage_tag\x18\x0e \x01(\x08\x12\x17\n\x0fusage_tag_graph\x18\x0f \x01(\x08\x12\x16\n\x0eusage_crosstag\x18\x10 \x01(\x08\x12\x1c\n\x14usage_crosstag_graph\x18\x11 \x01(\x08\x12\x14\n\x0cri_purchased\x18\x12 \x01(\x08\x12\x16\n\x0eri_utilization\x18\x13 \x01(\x08\x12\x19\n\x11ri_recommendation\x18\x14 \x01(\x08\x12\x14\n\x0csp_purchased\x18\x15 \x01(\x08\x12\x0f\n\x07invoice\x18\x16 \x01(\x08\x12%\n\x1dinvoice_download_csv_discount\x18\x17 \x01(\x08\x12#\n\x1binvoice_download_csv_merged\x18\x18 \x01(\x08\x12\x10\n\x08open_api\x18\x19 \x01(\x08\x12\x18\n\x10users_management\x18\x1a \x01(\x08\x12\x19\n\x11\x61q_coverage_ratio\x18\x1b \x01(\x08\x12\x18\n\x10\x61q_ri_management\x18\x1c \x01(\x08\x12\x18\n\x10\x61q_sp_management\x18\x1d \x01(\x08\x12\x1a\n\x12\x61q_ri_sp_instances\x18\x1e \x01(\x08\x12\x17\n\x0f\x61q_right_sizing\x18\x1f \x01(\x08\x12\x15\n\raq_scheduling\x18  \x01(\x08\x12\x16\n\x0ereport_filters\x18! \x01(\x08\x42Z\n\x19\x63loud.alphaus.blueapi.apiB\x15\x41piGroupRootUserProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_GROUPROOTUSER = _descriptor.Descriptor(
  name='GroupRootUser',
  full_name='blueapi.api.GroupRootUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='blueapi.api.GroupRootUser.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='blueapi.api.GroupRootUser.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='blueapi.api.GroupRootUser.groupId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupName', full_name='blueapi.api.GroupRootUser.groupName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupType', full_name='blueapi.api.GroupRootUser.groupType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='blueapi.api.GroupRootUser.meta', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passwordUpdateTime', full_name='blueapi.api.GroupRootUser.passwordUpdateTime', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateTime', full_name='blueapi.api.GroupRootUser.updateTime', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userAccessId', full_name='blueapi.api.GroupRootUser.userAccessId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='blueapi.api.GroupRootUser.userId', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveAvailabilityDays', full_name='blueapi.api.GroupRootUser.waveAvailabilityDays', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveRegistered', full_name='blueapi.api.GroupRootUser.waveRegistered', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveStatus', full_name='blueapi.api.GroupRootUser.waveStatus', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=345,
)


_FEATUREFLAGS = _descriptor.Descriptor(
  name='FeatureFlags',
  full_name='blueapi.api.FeatureFlags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dashboard_graph', full_name='blueapi.api.FeatureFlags.dashboard_graph', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_account', full_name='blueapi.api.FeatureFlags.usage_account', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_account_graph', full_name='blueapi.api.FeatureFlags.usage_account_graph', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_account_menu_account_edit', full_name='blueapi.api.FeatureFlags.usage_account_menu_account_edit', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_account_menu_budget', full_name='blueapi.api.FeatureFlags.usage_account_menu_budget', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_account_menu_budget_edit', full_name='blueapi.api.FeatureFlags.usage_account_menu_budget_edit', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_account_menu_fees_fee', full_name='blueapi.api.FeatureFlags.usage_account_menu_fees_fee', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_account_menu_fees_credit', full_name='blueapi.api.FeatureFlags.usage_account_menu_fees_credit', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_account_menu_fees_refund', full_name='blueapi.api.FeatureFlags.usage_account_menu_fees_refund', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_account_menu_fees_other_fees', full_name='blueapi.api.FeatureFlags.usage_account_menu_fees_other_fees', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_report_download', full_name='blueapi.api.FeatureFlags.usage_report_download', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_group', full_name='blueapi.api.FeatureFlags.usage_group', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_group_graph', full_name='blueapi.api.FeatureFlags.usage_group_graph', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_tag', full_name='blueapi.api.FeatureFlags.usage_tag', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_tag_graph', full_name='blueapi.api.FeatureFlags.usage_tag_graph', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_crosstag', full_name='blueapi.api.FeatureFlags.usage_crosstag', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_crosstag_graph', full_name='blueapi.api.FeatureFlags.usage_crosstag_graph', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ri_purchased', full_name='blueapi.api.FeatureFlags.ri_purchased', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ri_utilization', full_name='blueapi.api.FeatureFlags.ri_utilization', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ri_recommendation', full_name='blueapi.api.FeatureFlags.ri_recommendation', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sp_purchased', full_name='blueapi.api.FeatureFlags.sp_purchased', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoice', full_name='blueapi.api.FeatureFlags.invoice', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoice_download_csv_discount', full_name='blueapi.api.FeatureFlags.invoice_download_csv_discount', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoice_download_csv_merged', full_name='blueapi.api.FeatureFlags.invoice_download_csv_merged', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_api', full_name='blueapi.api.FeatureFlags.open_api', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users_management', full_name='blueapi.api.FeatureFlags.users_management', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aq_coverage_ratio', full_name='blueapi.api.FeatureFlags.aq_coverage_ratio', index=26,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aq_ri_management', full_name='blueapi.api.FeatureFlags.aq_ri_management', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aq_sp_management', full_name='blueapi.api.FeatureFlags.aq_sp_management', index=28,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aq_ri_sp_instances', full_name='blueapi.api.FeatureFlags.aq_ri_sp_instances', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aq_right_sizing', full_name='blueapi.api.FeatureFlags.aq_right_sizing', index=30,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aq_scheduling', full_name='blueapi.api.FeatureFlags.aq_scheduling', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report_filters', full_name='blueapi.api.FeatureFlags.report_filters', index=32,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=1304,
)

_GROUPROOTUSER.fields_by_name['meta'].message_type = _FEATUREFLAGS
DESCRIPTOR.message_types_by_name['GroupRootUser'] = _GROUPROOTUSER
DESCRIPTOR.message_types_by_name['FeatureFlags'] = _FEATUREFLAGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GroupRootUser = _reflection.GeneratedProtocolMessageType('GroupRootUser', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROOTUSER,
  '__module__' : 'api.grouprootuser_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.GroupRootUser)
  })
_sym_db.RegisterMessage(GroupRootUser)

FeatureFlags = _reflection.GeneratedProtocolMessageType('FeatureFlags', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREFLAGS,
  '__module__' : 'api.grouprootuser_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.FeatureFlags)
  })
_sym_db.RegisterMessage(FeatureFlags)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/utilization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/utilization.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\023ApiUtilizationProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15\x61pi/utilization.proto\x12\x0b\x62lueapi.api\"H\n\x0fUtilizationData\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\tchartData\x18\x02 \x03(\x0b\x32\x16.blueapi.api.ChartData\"q\n\tChartData\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x0c\n\x04\x63ost\x18\x03 \x01(\x01\x12\x0e\n\x06profit\x18\x04 \x01(\x01\x12\x13\n\x0butilization\x18\x05 \x01(\x01\x12\x12\n\ncommitment\x18\x06 \x01(\x01\x42X\n\x19\x63loud.alphaus.blueapi.apiB\x13\x41piUtilizationProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_UTILIZATIONDATA = _descriptor.Descriptor(
  name='UtilizationData',
  full_name='blueapi.api.UtilizationData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.UtilizationData.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chartData', full_name='blueapi.api.UtilizationData.chartData', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=110,
)


_CHARTDATA = _descriptor.Descriptor(
  name='ChartData',
  full_name='blueapi.api.ChartData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.ChartData.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='blueapi.api.ChartData.service', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='blueapi.api.ChartData.cost', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profit', full_name='blueapi.api.ChartData.profit', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='utilization', full_name='blueapi.api.ChartData.utilization', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commitment', full_name='blueapi.api.ChartData.commitment', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=225,
)

_UTILIZATIONDATA.fields_by_name['chartData'].message_type = _CHARTDATA
DESCRIPTOR.message_types_by_name['UtilizationData'] = _UTILIZATIONDATA
DESCRIPTOR.message_types_by_name['ChartData'] = _CHARTDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UtilizationData = _reflection.GeneratedProtocolMessageType('UtilizationData', (_message.Message,), {
  'DESCRIPTOR' : _UTILIZATIONDATA,
  '__module__' : 'api.utilization_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.UtilizationData)
  })
_sym_db.RegisterMessage(UtilizationData)

ChartData = _reflection.GeneratedProtocolMessageType('ChartData', (_message.Message,), {
  'DESCRIPTOR' : _CHARTDATA,
  '__module__' : 'api.utilization_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.ChartData)
  })
_sym_db.RegisterMessage(ChartData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/coverage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/coverage.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\020ApiCoverageProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12\x61pi/coverage.proto\x12\x0b\x62lueapi.api\"J\n\x0bOptionsData\x12\n\n\x02id\x18\x01 \x01(\t\x12/\n\x0coptionsChart\x18\x02 \x03(\x0b\x32\x19.blueapi.api.OptionsChart\"=\n\x0cOptionsChart\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x10\n\x08\x63overage\x18\x02 \x01(\x01\x12\r\n\x05usage\x18\x03 \x01(\x01\"M\n\x0cOndemandData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x31\n\rondemandChart\x18\x02 \x03(\x0b\x32\x1a.blueapi.api.OndemandChart\"l\n\rOndemandChart\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x17\n\x0fnormalizedUsage\x18\x03 \x01(\x01\x12\x14\n\x0condemandCost\x18\x04 \x01(\x01\x12\r\n\x05usage\x18\x05 \x01(\x01\x42U\n\x19\x63loud.alphaus.blueapi.apiB\x10\x41piCoverageProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_OPTIONSDATA = _descriptor.Descriptor(
  name='OptionsData',
  full_name='blueapi.api.OptionsData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.OptionsData.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optionsChart', full_name='blueapi.api.OptionsData.optionsChart', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=109,
)


_OPTIONSCHART = _descriptor.Descriptor(
  name='OptionsChart',
  full_name='blueapi.api.OptionsChart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.OptionsChart.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coverage', full_name='blueapi.api.OptionsChart.coverage', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='blueapi.api.OptionsChart.usage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=172,
)


_ONDEMANDDATA = _descriptor.Descriptor(
  name='OndemandData',
  full_name='blueapi.api.OndemandData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.OndemandData.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandChart', full_name='blueapi.api.OndemandData.ondemandChart', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=251,
)


_ONDEMANDCHART = _descriptor.Descriptor(
  name='OndemandChart',
  full_name='blueapi.api.OndemandChart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.OndemandChart.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='blueapi.api.OndemandChart.service', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalizedUsage', full_name='blueapi.api.OndemandChart.normalizedUsage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandCost', full_name='blueapi.api.OndemandChart.ondemandCost', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='blueapi.api.OndemandChart.usage', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=361,
)

_OPTIONSDATA.fields_by_name['optionsChart'].message_type = _OPTIONSCHART
_ONDEMANDDATA.fields_by_name['ondemandChart'].message_type = _ONDEMANDCHART
DESCRIPTOR.message_types_by_name['OptionsData'] = _OPTIONSDATA
DESCRIPTOR.message_types_by_name['OptionsChart'] = _OPTIONSCHART
DESCRIPTOR.message_types_by_name['OndemandData'] = _ONDEMANDDATA
DESCRIPTOR.message_types_by_name['OndemandChart'] = _ONDEMANDCHART
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OptionsData = _reflection.GeneratedProtocolMessageType('OptionsData', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONSDATA,
  '__module__' : 'api.coverage_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OptionsData)
  })
_sym_db.RegisterMessage(OptionsData)

OptionsChart = _reflection.GeneratedProtocolMessageType('OptionsChart', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONSCHART,
  '__module__' : 'api.coverage_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OptionsChart)
  })
_sym_db.RegisterMessage(OptionsChart)

OndemandData = _reflection.GeneratedProtocolMessageType('OndemandData', (_message.Message,), {
  'DESCRIPTOR' : _ONDEMANDDATA,
  '__module__' : 'api.coverage_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OndemandData)
  })
_sym_db.RegisterMessage(OndemandData)

OndemandChart = _reflection.GeneratedProtocolMessageType('OndemandChart', (_message.Message,), {
  'DESCRIPTOR' : _ONDEMANDCHART,
  '__module__' : 'api.coverage_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OndemandChart)
  })
_sym_db.RegisterMessage(OndemandChart)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/ripple/reseller.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from alphausblue.api import user_pb2 as api_dot_user__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/ripple/reseller.proto',
  package='blueapi.api.ripple',
  syntax='proto3',
  serialized_options=b'\n cloud.alphaus.blueapi.api.rippleB\026ApiRippleResellerProtoZ-github.com/alphauslabs/blue-sdk-go/api/ripple',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x61pi/ripple/reseller.proto\x12\x12\x62lueapi.api.ripple\x1a\x0e\x61pi/user.proto\"\xdc\x02\n\x08Reseller\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0f\n\x07groupId\x18\x03 \x01(\t\x12\x11\n\tgroupName\x18\x04 \x01(\t\x12\x11\n\tgroupType\x18\x05 \x01(\t\x12+\n\x08waveMeta\x18\x06 \x01(\x0b\x32\x19.blueapi.api.FeatureFlags\x12+\n\x08\x61quaMeta\x18\x07 \x01(\x0b\x32\x19.blueapi.api.FeatureFlags\x12\x1a\n\x12passwordUpdateTime\x18\x08 \x01(\t\x12\x12\n\nupdateTime\x18\t \x01(\t\x12\x14\n\x0cuserAccessId\x18\n \x01(\t\x12\x0e\n\x06userId\x18\x0b \x01(\t\x12\x1c\n\x14waveAvailabilityDays\x18\x0c \x01(\x05\x12\x16\n\x0ewaveRegistered\x18\r \x01(\t\x12\x12\n\nwaveStatus\x18\x0e \x01(\tBi\n cloud.alphaus.blueapi.api.rippleB\x16\x41piRippleResellerProtoZ-github.com/alphauslabs/blue-sdk-go/api/rippleb\x06proto3'
  ,
  dependencies=[api_dot_user__pb2.DESCRIPTOR,])




_RESELLER = _descriptor.Descriptor(
  name='Reseller',
  full_name='blueapi.api.ripple.Reseller',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='blueapi.api.ripple.Reseller.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='blueapi.api.ripple.Reseller.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='blueapi.api.ripple.Reseller.groupId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupName', full_name='blueapi.api.ripple.Reseller.groupName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupType', full_name='blueapi.api.ripple.Reseller.groupType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveMeta', full_name='blueapi.api.ripple.Reseller.waveMeta', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aquaMeta', full_name='blueapi.api.ripple.Reseller.aquaMeta', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passwordUpdateTime', full_name='blueapi.api.ripple.Reseller.passwordUpdateTime', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateTime', full_name='blueapi.api.ripple.Reseller.updateTime', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userAccessId', full_name='blueapi.api.ripple.Reseller.userAccessId', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='blueapi.api.ripple.Reseller.userId', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveAvailabilityDays', full_name='blueapi.api.ripple.Reseller.waveAvailabilityDays', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveRegistered', full_name='blueapi.api.ripple.Reseller.waveRegistered', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveStatus', full_name='blueapi.api.ripple.Reseller.waveStatus', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=414,
)

_RESELLER.fields_by_name['waveMeta'].message_type = api_dot_user__pb2._FEATUREFLAGS
_RESELLER.fields_by_name['aquaMeta'].message_type = api_dot_user__pb2._FEATUREFLAGS
DESCRIPTOR.message_types_by_name['Reseller'] = _RESELLER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Reseller = _reflection.GeneratedProtocolMessageType('Reseller', (_message.Message,), {
  'DESCRIPTOR' : _RESELLER,
  '__module__' : 'api.ripple.reseller_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.ripple.Reseller)
  })
_sym_db.RegisterMessage(Reseller)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio

from alphausblue.connection.conn import grpc_client_connection
from alphausblue.cost.v1.cost_pb2_grpc import CostStub
from alphausblue.cost.v1.cost_pb2 import ListAccountsRequest

async def main():
    
    # First, create the connection from a session
    conn = grpc_client_connection(svc = "cost")

    # Next, create the cost stub from the GRPC connection
    stub = CostStub(conn)

    # Finally, stream all the accounts for AWS from the connection
    async for account in stub.ListAccounts(ListAccountsRequest(vendor = "aws")):
        print(account)

if __name__ == '__main__':
    asyncio.run(main())